@@ -186,7 +186,6 @@ class FanStatus1C(DeviceStatus):
     """Container for status reports for Xiaomi Mi Smart Pedestal Fan DMaker 1C."""
 
     def __init__(self, data: Dict[str, Any]) -> None:
-        self.data = data
         """Response of a Fan1C (dmaker.fan.1c):
 
         {
@@ -204,6 +203,7 @@ class FanStatus1C(DeviceStatus):
           'exe_time': 280
         }
         """
+        self.data = data
 
     @property
     def power(self) -> str:
@@ -266,8 +266,7 @@ class FanMiot(MiotDevice):
         if model not in MIOT_MAPPING:
             raise FanException("Invalid FanMiot model: %s" % model)
 
-        super().__init__(ip, token, start_id, debug, lazy_discover)
-        self.model = model
+        super().__init__(ip, token, start_id, debug, lazy_discover, model=model)
 
     @command(
         default_output=format_output(
@@ -431,8 +430,7 @@ class Fan1C(MiotDevice):
         lazy_discover: bool = True,
         model: str = MODEL_FAN_1C,
     ) -> None:
-        super().__init__(ip, token, start_id, debug, lazy_discover)
-        self.model = model
+        super().__init__(ip, token, start_id, debug, lazy_discover, model=model)
 
     @command(
         default_output=format_output(
@@ -683,7 +681,7 @@ class FanZA5(MiotDevice):
         model: str = MODEL_FAN_ZA5,
     ) -> None:
         super().__init__(ip, token, start_id, debug, lazy_discover)
-        self.model = model
+        self._model = model
 
     @command(
         default_output=format_output(
