@@ -129,9 +129,11 @@ ROCKROBO_S5 = "roborock.vacuum.s5"
 ROCKROBO_S5_MAX = "roborock.vacuum.s5e"
 ROCKROBO_S6 = "roborock.vacuum.s6"
 ROCKROBO_S6_PURE = "roborock.vacuum.a08"
+ROCKROBO_T7S = "roborock.vacuum.a14"
 ROCKROBO_S7 = "roborock.vacuum.a15"
 ROCKROBO_S6_MAXV = "roborock.vacuum.a10"
 ROCKROBO_E2 = "roborock.vacuum.e2"
+ROCKROBO_1S = "roborock.vacuum.m1s"
 
 SUPPORTED_MODELS = [
     ROCKROBO_V1,
@@ -141,9 +143,11 @@ SUPPORTED_MODELS = [
     ROCKROBO_S5_MAX,
     ROCKROBO_S6,
     ROCKROBO_S6_PURE,
+    ROCKROBO_T7S,
     ROCKROBO_S7,
     ROCKROBO_S6_MAXV,
     ROCKROBO_E2,
+    ROCKROBO_1S,
 ]
 
 
@@ -606,7 +610,7 @@ class RoborockVacuum(Device):
         elif self.model == ROCKROBO_E2:
             fanspeeds = FanspeedE2
         elif self.model == ROCKROBO_S7:
-            self._fanspeeds = FanspeedS7
+            fanspeeds = FanspeedS7
         else:
             fanspeeds = FanspeedV2
 
